package com.ibm.etools.iseries.examples.dfu.FormManagerWithFilter;

// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This a condition class used by RecordIOManager object in 
 * sample FormManagerWithFilter. This class is to filter all the
 * records with database field "BRANCH" equals "12345".
 * A condition class must extends com.ibm.etools.iseries.ui.AbstractCondition.
 */

import com.ibm.etools.iseries.ui.AbstractCondition;
import com.ibm.as400.access.*;
import java.math.BigDecimal;
import java.text.Collator;
import java.util.Locale;


public class FilterBranchEQ12345 extends AbstractCondition 
{
	/**
	 * Compare the value in a database field with the value specified
	 * in argument compareValue. If the values are equals, returns 
	 * true; otherwise returns false.
	 */	
	public boolean compareEqual(java.lang.Object fieldValue, com.ibm.as400.access.AS400DataType dataType, java.lang.String compareValue)
	{
		boolean condResult = false;
		Collator collator = Collator.getInstance(Locale.getDefault());
		collator.setStrength(Collator.PRIMARY);
		collator.setDecomposition(Collator.NO_DECOMPOSITION);
  
  		// Database field can be of different data types, whereas the 
  		// value specified in argument compareValue is String. We must
  		// convert them to the equivalent java types before doing the
  		// comparison. If the comparison is equal, then condResult is 
  		// set to true; otherwise it is set to false.
		if (dataType instanceof AS400Text)
		{
			if (collator.compare(fieldValue.toString().trim(), compareValue) == 0)
				condResult = true;
  		}
		else if (dataType instanceof AS400ByteArray)
		{
			if (collator.compare(fieldValue.toString().trim(), compareValue) == 0)
				condResult = true;
		}
		else if (dataType instanceof AS400PackedDecimal ||
			dataType instanceof AS400ZonedDecimal)
		{
			if (((BigDecimal)fieldValue).compareTo(new BigDecimal(compareValue)) == 0)
				condResult = true;
		}
		else if (dataType instanceof AS400Bin2)
		{
			if (((Short)fieldValue).compareTo(new Short(compareValue)) == 0)
				condResult = true;
		}
		else if (dataType instanceof AS400Bin4 ||
				dataType instanceof AS400UnsignedBin2)
		{
			if (((Integer)fieldValue).compareTo(new Integer(compareValue)) == 0)
				condResult = true;
		}
		else if (dataType instanceof AS400UnsignedBin4)
		{
			if (((Long)fieldValue).compareTo(new Long(compareValue)) == 0)
				condResult = true;
		}
		else if (dataType instanceof AS400Float4)
		{
			if (((Float)fieldValue).compareTo(new Float(compareValue)) == 0)
				condResult = true;
		}
		else if (dataType instanceof AS400Float8)
		{
			if (((Double)fieldValue).compareTo(new Double(compareValue)) == 0)
				condResult = true;
		}
  		
  		return condResult;
	}


	/**
	 * The method will be called to determine which records will be filtered.
	 * If the record retrieved passes the condition set in this method,
	 * then returns true; otherwise returns false.
	 */
	public boolean isConditionValid(com.ibm.as400.access.Record currentRecord) 
	{
		boolean result = false;
		String[] columnNames = {"BRANCH"};
		String[] compareValues = {"12345"};
		int[] fdIndex = new int[1];
		AS400DataType[] dataType = new AS400DataType[1];
		boolean[] condResult = new boolean[1];


		try
		{
			// From currentRecord, look for the field named "BRANCH"
			FieldDescription[] fd = currentRecord.getRecordFormat().getFieldDescriptions();
			for (int i=0; i<fd.length; i++)
			{
				if (fd[i].getFieldName().equals("BRANCH"))
				{
					fdIndex[0] = i;
				}
			}
			
			// Get the data type of the field
			dataType[0] = fd[fdIndex[0]].getDataType();
			
			// Compare if the value in the database field is equal to "12345"
			condResult[0] = compareEqual(currentRecord.getField(columnNames[0]), dataType[0], compareValues[0]);
			if (condResult[0]) result = true;
		}
		catch (Throwable e) {}

		return result;
	}


}
