package com.ibm.etools.iseries.examples.dfu.MultiRecordFormatLogicalForm;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2000 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 *
 * This sample program demonstrates how you can use FormManager with
 * a logical file. The sample shows the record in two record formats
 * in different pages of a tabbed pane.
 *
 * Functions that you can perform with the example:
 * 1) By clicking button "Next Order", a sign on dialog will pop
 * up for you to log on to your server, then it will retrieve
 * the next record from logical file "MULTIRECL" in library "ADTSLAB".
 * Data from record format INVREC are displayed in tab "INVREC", and
 * data from record format SALESREC are displayed in tab "SALESREC"
 *  
 */ 

import javax.swing.*;
import com.ibm.etools.iseries.ui.*;

public class MultiRecordFormatLogicalForm extends JFrame implements java.awt.event.ActionListener
{

	private JTabbedPane 	tabbedPane 		= null;
	private JPanel 			invRecPage 		= null;
	private JPanel 			salesRecPage 	= null;
	private JTextField 		tCusord 		= null;
	private JTextField 		tCust 			= null;
	private JTextField 		tGoods 			= null;
	private JTextField 		tOrddate 		= null;
	private JTextField 		tPrice 			= null;
	private JTextField 		tSaledate 		= null;
	private JTextField 		tSalesman 		= null;
	private JTextField 		tShpto 			= null;
	private JTextField 		tShpvia 		= null;
	private JButton 		bNextOrder 		= null;
	private JLabel 			lOrder 			= null;
	private com.ibm.as400.access.AS400 as400 = null;
	private com.ibm.etools.iseries.ui.FormManager formManager1 = null;
	private com.ibm.etools.iseries.ui.FormManager formManager2 = null;


/**
 * MultiRecordFormatLogicalForm constructor.
 */
public MultiRecordFormatLogicalForm() {
	super("FormManager with a multiple record format logical file");
		setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		setSize(547, 446);
		setContentPane(getJFrameContentPane());
}

public void actionPerformed(java.awt.event.ActionEvent e) 
{
	Object obj = e.getSource();
	
	try
	{
		if (obj == bNextOrder) 
		{
			getFormManager1().readNextRecord();
			getFormManager2().readNextRecord();
		}
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
}
/**
 * Return the AS4001 property value.
 * @return com.ibm.as400.access.AS400
 */
private com.ibm.as400.access.AS400 getAS400() 
{
	if (as400 == null) 
	{
		try 
		{
			as400 = new com.ibm.as400.access.AS400();
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return as400;
}
/**
 * Return the FormManager1 property value.
 * @return com.ibm.etools.iseries.ui.FormManager
 */
private com.ibm.etools.iseries.ui.FormManager getFormManager1() 
{
	if (formManager1 == null) 
	{
		try 
		{
			// Instantiate formManager1.
			// Associate formManager with a logical file "MULTIRECL" in
			// library "ADTSLAB", and select "INVREC" as the record
			// format to use.
			formManager1 = new FormManager();
			RecordIOManager recIOMgr = new RecordIOManager("MULTIRECL","ADTSLAB");
			recIOMgr.setRecordFormatName("INVREC");
			formManager1.setRecordIOManager(recIOMgr);
		
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return formManager1;
}
/**
 * Return the FormManager2 property value.
 * @return com.ibm.etools.iseries.ui.FormManager
 */
private com.ibm.etools.iseries.ui.FormManager getFormManager2() 
{
	if (formManager2 == null) 
	{
		try 
		{
			// Instantiate formManager2.
			// Associate formManager with a logical file "MULTIRECL" in
			// library "ADTSLAB", and select "SALESREC" as the record
			// format to use.
			formManager2 = new FormManager();
			RecordIOManager recIOMgr = new RecordIOManager("MULTIRECL","ADTSLAB");
			recIOMgr.setRecordFormatName("SALESREC");
			formManager2.setRecordIOManager(recIOMgr);
		
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return formManager2;
}
/**
 * Return the JFrameContentPane property value.
 * @return JPanel
 */
private JPanel getJFrameContentPane() 
{
	JPanel contentPane = new JPanel();
	contentPane.setLayout(null);
	
	JLabel label1 = new JLabel();
	label1.setName("JLabel1");
	label1.setText("Order:");
	label1.setBounds(19, 21, 52, 20);
	contentPane.add(label1);
			
	tabbedPane = new JTabbedPane();
	tabbedPane.setTabPlacement(JTabbedPane.RIGHT);
	tabbedPane.insertTab("INVREC", null, getInvRecPage(), null, 0);
	tabbedPane.insertTab("SALESREC", null, getSalesRecPage(), null, 1);
	tabbedPane.setBounds(19, 57, 504, 321);
	contentPane.add(tabbedPane);
	
	bNextOrder = new JButton("Next Order");
	bNextOrder.setBounds(334, 18, 183, 26);
	contentPane.add(bNextOrder);
	
	lOrder = new JLabel();
	lOrder.setName("ORDER");
	lOrder.setBorder(new javax.swing.border.EtchedBorder());
	lOrder.setBounds(68, 21, 147, 20);
	lOrder.setForeground(java.awt.Color.black);
	contentPane.add(lOrder);

	bNextOrder.addActionListener(this);

	getFormManager1().setSystem(getAS400());
	getFormManager2().setSystem(getAS400());
	getFormManager1().setDisplayContainer(contentPane);
	getFormManager2().setDisplayContainer(contentPane);
	
	return contentPane;
}
private JPanel getSalesRecPage() 
{
	if (salesRecPage == null) 
	{
		salesRecPage = new JPanel();
		salesRecPage.setLayout(null);
			
		JLabel label2 = new JLabel("Sale date");
		label2.setBounds(11, 21, 72, 22);
		salesRecPage.add(label2);
		
		JLabel label3 = new JLabel("Salesman");
		label3.setBounds(11, 70, 72, 22);
		salesRecPage.add(label3);

		tSaledate = new JTextField();
		tSaledate.setName("SALEDATE");
		tSaledate.setBounds(98, 20, 213, 26);
		tSaledate.setEditable(false);
		salesRecPage.add(tSaledate);
			
		tSalesman = new JTextField();
		tSalesman.setName("SALESMAN");
		tSalesman.setBounds(98, 66, 213, 26);
		tSalesman.setEditable(false);
		salesRecPage.add(tSalesman);
	}
	return salesRecPage;
}
private JPanel getInvRecPage() 
{
	if (invRecPage == null) 
	{
		invRecPage = new JPanel();
		invRecPage.setLayout(null);
		
		JLabel label4 = new JLabel("Order Date");
		label4.setBounds(12, 22, 111, 19);
		invRecPage.add(label4);
			
		JLabel label5 = new JLabel("Customer Order");
		label5.setBounds(12, 63, 111, 19);
		invRecPage.add(label5);
			
		JLabel label6 = new JLabel("Customer");
		label6.setBounds(12, 104, 111, 19);
		invRecPage.add(label6);
			
		JLabel label7 = new JLabel("Ship Via");
		label7.setBounds(12, 145, 111, 19);
		invRecPage.add(label7);
			
		JLabel label8 = new JLabel("Ship To");
		label8.setBounds(12, 186, 111, 19);
		invRecPage.add(label8);
			
		JLabel label9 = new JLabel("Price");
		label9.setBounds(12, 227, 111, 19);
		invRecPage.add(label9);

		JLabel label10 = new JLabel("Goods");
		label10.setBounds(12, 268, 111, 19);
		invRecPage.add(label10);
			
		tOrddate = new JTextField();
		tOrddate.setName("ORDDATE");
		tOrddate.setBounds(117, 19, 177, 22);
		tOrddate.setEditable(false);
		invRecPage.add(tOrddate);
		
		tCusord = new JTextField();
		tCusord.setName("CUSORD");
		tCusord.setBounds(117, 61, 177, 22);
		tCusord.setEditable(false);
		invRecPage.add(tCusord);

		tCust = new JTextField();
		tCust.setName("CUST");
		tCust.setBounds(117, 103, 177, 22);
		tCust.setEditable(false);
		invRecPage.add(tCust);
		
		tShpvia = new JTextField();
		tShpvia.setName("SHPVIA");
		tShpvia.setBounds(117, 145, 177, 22);
		tShpvia.setEditable(false);
		invRecPage.add(tShpvia);
		
		tShpto = new JTextField();
		tShpto.setName("SHPTO");
		tShpto.setBounds(117, 187, 177, 22);
		tShpto.setEditable(false);
		invRecPage.add(tShpto);

		tPrice = new JTextField();
		tPrice.setName("PRICE");
		tPrice.setBounds(117, 229, 177, 22);
		tPrice.setEditable(false);
		invRecPage.add(tPrice);

		tGoods = new JTextField();
		tGoods.setName("GOODS");
		tGoods.setBounds(117, 271, 177, 22);
		tGoods.setEditable(false);
		invRecPage.add(tGoods);
	}
	return invRecPage;
}
/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) {
	try {
		MultiRecordFormatLogicalForm aMultiRecordFormatLogicalForm;
		aMultiRecordFormatLogicalForm = new MultiRecordFormatLogicalForm();
		aMultiRecordFormatLogicalForm.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aMultiRecordFormatLogicalForm.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}
}
