package com.ibm.etools.iseries.examples.dfu.RecordIOManagerSample;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 *
 * This sample program demonstrates the use of RecordIOManager.
 * RecordIOManager does not tie to any Swing component.
 *
 * This sample associate a RecordIOManager object with database
 * "PRODDTL" in library "ADTSLAB". It demonstrates the use of
 * openFile(), closeFile(), readAllRecords(), updateRecord(DefaultTableModel),
 * updateRecord(String[], DefaultTableModel), addRecord(DefaultTableModel),
 * deleteRecord(int[]), deleteRecord(String[]), commit(), and rollback().
 * The sample will first open the database "PRODDTL" and retrieve all the 
 * records. Since the sample did not explicitly set the server name, 
 * user id and password, a sign on dialog will appear. Sign on to your
 * iSeries server, then the sample will list the column names of the 
 * database in format libraryName.DatabaseName.FieldName.
 * Then it will list each record in ascending order by PARTNO key, and
 * then do two updates, one add and two delete operations.
 * At the end, the sample will close the database file and exit. 
 * 
 */

import com.ibm.etools.iseries.ui.RecordIOManager;
import javax.swing.table.DefaultTableModel;
import java.math.BigDecimal;

public class RecordIOManagerSample
{
	private RecordIOManager recIOManager;

/**
 * Constructor
 */
public RecordIOManagerSample() 
{
	try
	{
		// Associate RecordIOManager with database PRODUCT in library ADTSLAB
		// By default if record format is not specified, the first record
		// format is used and the database is in keyed access.
		recIOManager = new RecordIOManager("PRODDTL","ADTSLAB");
		recIOManager.setCommitLockLevel(RecordIOManager.COMMITLOCKLEVEL_CHANGE);		
	}
	catch (Throwable e)
	{
		e.printStackTrace();
	}

}


public void readAll() 
{
	try
	{
		// retrieve all the records from the database, data returned are
		// stored in a DefaultTableModel. A logon dialog will pop up
		// for you to signon. If you do not want the signon dialog
		// to come up, you can setServer, setUserid and setPassword.
		DefaultTableModel model = recIOManager.readAllRecords();
		
		// print the column names of the database
		System.out.println("Columns from database PRODDTL:");
		for (int i=0; i< model.getColumnCount(); i++)
		{
			System.out.print(model.getColumnName(i) + ", ");
		}
		System.out.println("");
		
		// print all the records retrieved from the database
		System.out.println("Records retrieved from database PRODDTL:");
		for (int row=0; row<model.getRowCount(); row++)
		{
			for (int col=0; col<model.getColumnCount(); col++)
			{
				System.out.print(model.getValueAt(row, col)+", ");
			}
			System.out.println("");
		}

	}
	catch (Throwable e)
	{
		e.printStackTrace();
	}

}

public void updateWithARead()
{
	DefaultTableModel record;
	int inventoryColNo = -1;
	int inventory = 0;
	BigDecimal newQty = null;
	
	try 
	{
		// read the record by key with value 00010
		record = recIOManager.readRecord(new String[]{"00010"});
		
		// get the column number for field INVENTORY in record
		inventoryColNo = findColumn(record, "ADTSLAB.PRODDTL.INVENTORY");
		
		// get the value for field INVENTORY
		inventory = ((BigDecimal) record.getValueAt(0, inventoryColNo)).intValue();
		
		// deduct inventory quantity by 1
		if (inventory -1 >= 0)
		{
			// change to newQty value
			newQty = new BigDecimal(inventory - 1);
			record.setValueAt(newQty, 0, inventoryColNo);
			
			// do the update
			recIOManager.updateRecord(record);
	
			// commit the changes	
			recIOManager.commit();
		}
	}
	catch (Exception e) 
	{
		e.printStackTrace();
	}	
}

public void updateByKey()
{
	try 
	{
		// create DefaultTableModel that holds the value of INVENTORY column
		// that needs to be update.
		DefaultTableModel updateRecord = new DefaultTableModel(1,1);
		updateRecord.setDataVector(new Object[][]{ { new BigDecimal(50) } },
						   new Object[]{ "ADTSLAB.PRODDTL.INVENTORY" });

		// read the record by key with value 00010
		recIOManager.updateRecord(new String[]{"00010"}, updateRecord);

		// commit the changes	
		recIOManager.commit();
	}
	catch (Exception e) 
	{
		e.printStackTrace();
	}	
}

public void deleteWithARead()
{
	DefaultTableModel record;
	int[] recordNumber = new int[]{-1};
	
	try 
	{
		// read the record whose key value is 00099
		record = recIOManager.readRecord(new String[]{"00099"});
		
		// the first column of DefaultTableModel returned is the recordNumber
		recordNumber[0] = new Integer(((String)record.getValueAt(0,0))).intValue();			
		
		// delete the record that have just read
		recIOManager.deleteRecord(recordNumber);
	
		// commit the changes
		recIOManager.commit();
	}
	catch (Exception e) 
	{
		e.printStackTrace();
	}	
}

public void deleteByKey()
{
	try 
	{
		// delete the record whose key value is 00010
		recIOManager.deleteRecord(new String[]{"00010"});

		// rollback the changes	from the last commit
		recIOManager.rollback();
	}
	catch (Exception e) 
	{
		e.printStackTrace();
	}	
}

public void add()
{
	try 
	{
		// create DefaultTableModel that holds the values of the new record
		// to be added
		DefaultTableModel newRecord = new DefaultTableModel(1,6);
		newRecord.setDataVector(new Object[][]{ { 	"00099",
													"m99",
													new BigDecimal(123),
													"2002-05-06",
													"Testing",
													"c:/test/test.gif" } },
						   		new Object[]{	"ADTSLAB.PRODDTL.PARTNO",
						   					 	"ADTSLAB.PRODDTL.MODEL",
						   				 		"ADTSLAB.PRODDTL.INVENTORY",
						   				 		"ADTSLAB.PRODDTL.PARTSHIP",
						   				 		"ADTSLAB.PRODDTL.PARTD",
						   				 		"ADTSLAB.PRODDTL.PARTPIC" });

		// add the new record
		recIOManager.addRecord(newRecord);

		// commit the changes
		recIOManager.commit();
	}
	catch (Exception e) 
	{
		e.printStackTrace();
	}	

}

public void open()
{
	try
	{
		// open the database
		recIOManager.openFile();
	}
	catch (Throwable e)
	{
		e.printStackTrace();
	}
		
}

public void close()
{
	try
	{
		// close the database
		recIOManager.closeFile();
	}
	catch (Throwable e)
	{
		e.printStackTrace();
	}
		
}

private int findColumn(DefaultTableModel record, String columnName)
{
	for (int i=0; i<record.getColumnCount(); i++)
	{
		if (record.getColumnName(i).equals(columnName))
			return i;
	}
	return -1;
}

public static void main(java.lang.String[] args) 
{
	RecordIOManagerSample sample = new RecordIOManagerSample();
	
	// open the file
	sample.open();
	
	// read all records from the database
	sample.readAll();
	
	// demonstrate two different ways to update, first one is 
	// to perform a read before an update, second one is just to
	// provide the keys, the method will implicitly perform a
	// read and then update.
	sample.updateWithARead();
	sample.updateByKey();
	
	// add a record to the database
	sample.add();
	
	// demonstrate two different ways to delete, first one is 
	// to perform a read before the delete, second one is just to
	// provide the keys, the method will implicitly perform a
	// read and then delete. However, a rollback is performed at the 
	// end of each delete, so the actual deletion is not performed.
	sample.deleteWithARead();
	sample.deleteByKey();
	
	// close the file
	sample.close();
	System.exit(0);
}

}
